<?php
/**
 * Plugin Name: Proof Tracker
 * Description: Management for digital proofs
 * Version: 1.0
 * Author: WebCraft Studios
 * License: GPLv2 or later
 * License URI: https://www.gnu.org/licenses/gpl-2.0.html
 */

 if ( ! defined( 'ABSPATH' ) ) {
    exit; // Exit if accessed directly.
}

add_action('admin_menu', 'proof_tracker_create_menu');


/**
 * Function to create menu and submenu pages
 */
function proof_tracker_create_menu() {
    // Create the top-level menu
    add_menu_page(
        'Proof Tracker Dashboard',  // Page title
        'Proof Tracker',            // Menu title
        'manage_options',           // Capability
        'dashboard',                // Menu slug
        'proof_tracker_dashboard_page', // Function to display the page content
        plugins_url('proof-tracker/logo.ico'),      // Icon
        6                           // Position
    );

    add_submenu_page(
        'dashboard', 'Proofs', 'Proofs', 'manage_options', 'proofs', 'proof_tracker_proofs_page'
    );

    add_submenu_page(
        'dashboard', 'Drop Box', 'Drop Box', 'manage_options', 'drop-box', 'proof_tracker_drop_box_page'
    );

    add_submenu_page(
        'dashboard', 'Settings', 'Settings', 'manage_options', 'settings', 'proof_tracker_setting_page'
    );

    add_submenu_page(
        'dashboard', 'Supports', 'Supports', 'manage_options', 'supports', 'proof_tracker_support_page'
    );

    add_submenu_page(
        '', 'Create new Proof', 'Create new Proof', 'manage_options', 'create-proof', 'proof_tracker_create_page'
    );


}

/**
 * Function to add custom meta box on WooCommerce order admin page
 */

add_action('woocommerce_admin_order_data_after_payment_info', 'proof_tracker_custom_order_section');

// add_action('add_meta_boxes', 'proof_tracker_add_custom_meta_box');


function proof_tracker_custom_order_section($post) {
    // Get the WooCommerce Order object from the $post object
    $order = wc_get_order($post->ID);
    
    // Ensure you have a valid WooCommerce Order object
    if (!$order) {
        return;
    }

    // Get the order ID
    $order_id = $order->get_id();

    // Create the new URL with the order ID as a query parameter
    $new_url = admin_url('admin.php?page=create-proof&id=' . $order_id);

    // Output a button that navigates to the new URL with an image icon
    echo '<div class="proof-tracker-meta-box-content" style="width: 10rem; padding: 10px;">';
    echo '<a href="' . esc_url($new_url) . '" class="button button-primary" target="_blank" style="display: flex; align-items: center; background-color: #f88038">';
    echo '<img src="https://res.cloudinary.com/djqqn4rpp/image/upload/v1728771102/o9qncm3l5tcbr0sccz2d.ico" alt="Icon" style="width: 16px; height: 15px; margin-right: 5px;">'; // Icon image
    echo 'Open Proof Tracker</a>';
    echo '</div>';
}


function proof_tracker_create_page() {
    // Check if the 'id' parameter is set in the URL
    $custom_id = isset($_GET['id']) ? intval($_GET['id']) : 0;

    // Show order number
    echo '<p>Order Number: #' . esc_html($custom_id) . '</p>';

    if ($custom_id <= 0) {
        echo '<p>No custom ID provided.</p>';
        return;
    }

    // Check if the nonce is set, unslash and sanitize it before verification
    // $nonce = isset($_GET['_wpnonce']) ? sanitize_text_field(wp_unslash($_GET['_wpnonce'])) : '';

    // if (!$nonce || !wp_verify_nonce($nonce, 'proof_tracker_nonce_action')) {
    //     wp_die('Invalid request');
    // }


    $new_url = 'https://wordpress-dashboard.proof-tracker.com/proof-tracker?id=' . $custom_id;

    echo '<div class="proof-tracker-meta-box-content" style="width: 100%; height: 100vh; padding: 0; margin: 0;">';
    echo '<iframe src="' . esc_url($new_url) . '" title="Create new Proof" style="width: 100%; height: 100%; border: none;"></iframe>';
    echo '</div>';
}


function proof_tracker_dashboard_page() {

    ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Proof Tracker Dashboard</title>
            <style>
               
                body, html {
                    margin: 0;
                    padding: 0;
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    overflow: hidden;
                }

                iframe {
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    border: none; 
                }
            </style>
        </head>
        <body>
            <iframe src="https://wordpress-dashboard.proof-tracker.com/dashboard"  title="Proof Tracker Dashboard"></iframe>
        </body>
        </html>

    <?php
}

function proof_tracker_proofs_page() {
    ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Proof Tracker Dashboard</title>
            <style>
            
                body, html {
                    margin: 0;
                    padding: 0;
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    overflow: hidden;
                }

                iframe {
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    border: none; 
                }
            </style>
        </head>
        <body>
            <iframe src="https://wordpress-dashboard.proof-tracker.com/proofs" title="Proof Tracker Dashboard"></iframe>
        </body>
        </html>

    <?php
}


function proof_tracker_drop_box_page() {
    ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Proof Tracker Dashboard</title>
            <style>
               
                body, html {
                    margin: 0;
                    padding: 0;
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    overflow: hidden;
                }

                iframe {
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    border: none; 
                }
            </style>
        </head>
        <body>
            <iframe src="https://wordpress-dashboard.proof-tracker.com/drop-box" title="Proof Tracker Drop Box"></iframe>
        </body>
        </html>

    <?php
}



function proof_tracker_support_page() {
    ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Proof Tracker Supports</title>
            <style>
               
                body, html {
                    margin: 0;
                    padding: 0;
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    overflow: hidden;
                }

                iframe {
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    border: none; 
                }
            </style>
        </head>
        <body>
            <iframe src="https://wordpress-dashboard.proof-tracker.com/supports" title="Proof Tracker Supports"></iframe>
        </body>
        </html>

    <?php
}


function proof_tracker_setting_page() {
    ?>
        <!DOCTYPE html>
        <html lang="en">
        <head>
            <meta charset="UTF-8">
            <meta name="viewport" content="width=device-width, initial-scale=1.0">
            <title>Proof Tracker Settings</title>
            <style>
               
                body, html {
                    margin: 0;
                    padding: 0;
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    overflow: hidden;
                }

                iframe {
                    width: 100%;
                    height: 100%;
                    min-height: 100vh;
                    border: none; 
                }
            </style>
        </head>
        <body>
            <iframe src="https://wordpress-dashboard.proof-tracker.com/setting" title="Proof Tracker Settings"></iframe>
        </body>
        </html>

    <?php
}
